@@ -1,15 +1,16 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2020 pyglet contributors
 # All rights reserved.
-# 
+#
 # Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions 
+# modification, are permitted provided that the following conditions
 # are met:
 #
 #  * Redistributions of source code must retain the above copyright
 #    notice, this list of conditions and the following disclaimer.
-#  * Redistributions in binary form must reproduce the above copyright 
+#  * Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in
 #    the documentation and/or other materials provided with the
 #    distribution.
@@ -32,43 +33,43 @@
 # POSSIBILITY OF SUCH DAMAGE.
 # ----------------------------------------------------------------------------
 
-'''Read GIF control data.
+"""Read GIF control data.
 
 http://www.w3.org/Graphics/GIF/spec-gif89a.txt
-'''
-from __future__ import print_function
-from __future__ import division
-from builtins import object
-
-__docformat__ = 'restructuredtext'
-__version__ = '$Id$'
+"""
 
 import struct
 
 from pyglet.image.codecs import ImageDecodeException
 
-class GIFStream(object):
+
+class GIFStream:
     def __init__(self):
         self.images = []
 
-class GIFImage(object):
+
+class GIFImage:
     delay = None
 
-class GraphicsScope(object):
+
+class GraphicsScope:
     delay = None
 
+
 # Appendix A.
 LABEL_EXTENSION_INTRODUCER = 0x21
 LABEL_GRAPHIC_CONTROL_EXTENSION = 0xf9
 LABEL_IMAGE_DESCRIPTOR = 0x2c
 LABEL_TRAILER = 0x3b
 
-def unpack(format, file):
-    size = struct.calcsize(format)
+
+def unpack(fmt, file):
+    size = struct.calcsize(fmt)
     data = file.read(size)
     if len(data) < size:
         raise ImageDecodeException('Unexpected EOF')
-    return struct.unpack(format, data)
+    return struct.unpack(fmt, data)
+
 
 def read_byte(file):
     data = file.read(1)
@@ -76,11 +77,12 @@ def read_byte(file):
         raise ImageDecodeException('Unexpected EOF')
     return ord(data)
 
+
 def read(file):
-    '''Read a GIF file stream.
+    """Read a GIF file stream.
 
     :rtype: GIFStream
-    '''
+    """
     # 17. Header
     signature = file.read(3)
     version = file.read(3)
@@ -92,7 +94,7 @@ def read(file):
     # 18. Logical screen descriptor
     (logical_screen_width,
      logical_screen_height,
-     fields, 
+     fields,
      background_color_index,
      pixel_aspect_ratio) = unpack('HHBBB', file)
     global_color_table_flag = fields & 0x80
@@ -123,7 +125,8 @@ def read(file):
         block_type = read_byte(file)
 
     return stream
-        
+
+
 def skip_data_sub_blocks(file):
     # 15. Data sub-blocks
     block_size = read_byte(file)
@@ -131,11 +134,12 @@ def skip_data_sub_blocks(file):
         data = file.read(block_size)
         block_size = read_byte(file)
 
+
 def read_table_based_image(file, stream, graphics_scope):
     gif_image = GIFImage()
     stream.images.append(gif_image)
     gif_image.delay = graphics_scope.delay
-        
+
     # 20. Image descriptor
     (image_left_position,
      image_top_position,
@@ -154,6 +158,7 @@ def read_table_based_image(file, stream, graphics_scope):
     lzw_code_size = file.read(1)
     skip_data_sub_blocks(file)
 
+
 def read_graphic_control_extension(file, stream, graphics_scope):
     # 23. Graphic control extension
     (block_size,
@@ -163,7 +168,7 @@ def read_graphic_control_extension(file, stream, graphics_scope):
      terminator) = unpack('BBHBB', file)
     if block_size != 4:
         raise ImageDecodeException('Incorrect block size')
-    
+
     if delay_time:
         # Follow Firefox/Mac behaviour: use 100ms delay for any delay
         # less than 10ms.
