@@ -40,10 +40,10 @@ such as Rectangles, Circles, and Lines. These shapes are are made
 internally from OpenGL primitives, and provide excellent performance
 when drawn as part of a :py:class:`~pyglet.graphics.Batch`.
 Convenience methods are provided for positioning, changing color
-and opacity, and rotation (where applicible). If you need to create
-something more complex than what is provided here, the lower level
+and opacity, and rotation (where applicible). To create more
+complex shapes than what is provided here, the lower evel
 graphics API is more appropriate.
-See the :ref:`programming-guide-graphics` for more details.
+See the :ref:`guide_graphics` for more details.
 
 A simple example of drawing shapes::
 
@@ -76,7 +76,7 @@ A simple example of drawing shapes::
 import math
 
 from pyglet.gl import GL_COLOR_BUFFER_BIT, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA
-from pyglet.gl import GL_TRIANGLES, GL_LINES, GL_MULTISAMPLE, GL_BLEND
+from pyglet.gl import GL_TRIANGLES, GL_TRIANGLE_STRIP, GL_LINES, GL_BLEND
 from pyglet.gl import glPushAttrib, glPopAttrib, glBlendFunc, glEnable, glDisable
 from pyglet.graphics import Group, Batch
 
@@ -112,11 +112,9 @@ class _ShapeGroup(Group):
         glPushAttrib(GL_COLOR_BUFFER_BIT)
         glEnable(GL_BLEND)
         glBlendFunc(self.blend_src, self.blend_dest)
-        glEnable(GL_MULTISAMPLE)
 
     def unset_state(self):
         glDisable(GL_BLEND)
-        glDisable(GL_MULTISAMPLE)
         glPopAttrib()
 
     def __eq__(self, other):
@@ -310,7 +308,7 @@ class _ShapeBase:
 
 
 class Arc(_ShapeBase):
-    def __init__(self, x, y, radius, segments=25, angle=math.pi*2, color=(255, 255, 255), batch=None, group=None):
+    def __init__(self, x, y, radius, segments=25, angle=math.pi * 2, color=(255, 255, 255), batch=None, group=None):
         # TODO: Finish this shape and add docstring.
         self._x = x
         self._y = y
@@ -322,7 +320,7 @@ class Arc(_ShapeBase):
         self._batch = batch or Batch()
         self._group = _ShapeGroup(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA, group)
 
-        self._vertex_list = self._batch.add(self._segments*2, GL_LINES, self._group, 'v2f', 'c4B')
+        self._vertex_list = self._batch.add(self._segments * 2, GL_LINES, self._group, 'v2f', 'c4B')
         self._update_position()
         self._update_color()
 
@@ -342,7 +340,7 @@ class Arc(_ShapeBase):
             # Create a list of doubled-up points from the points:
             vertices = []
             for i, point in enumerate(points):
-                line_points = *points[i-1], *point
+                line_points = *points[i - 1], *point
                 vertices.extend(line_points)
 
         self._vertex_list.vertices[:] = vertices
@@ -393,7 +391,7 @@ class Circle(_ShapeBase):
         self._batch = batch or Batch()
         self._group = _ShapeGroup(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA, group)
 
-        self._vertex_list = self._batch.add(self._segments*3, GL_TRIANGLES, self._group, 'v2f', 'c4B')
+        self._vertex_list = self._batch.add(self._segments * 3, GL_TRIANGLES, self._group, 'v2f', 'c4B')
         self._update_position()
         self._update_color()
 
@@ -413,7 +411,7 @@ class Circle(_ShapeBase):
             # Create a list of trianges from the points:
             vertices = []
             for i, point in enumerate(points):
-                triangle = x, y, *points[i-1], *point
+                triangle = x, y, *points[i - 1], *point
                 vertices.extend(triangle)
 
         self._vertex_list.vertices[:] = vertices
@@ -662,3 +660,93 @@ class Rectangle(_ShapeBase):
     def rotation(self, rotation):
         self._rotation = rotation
         self._update_position()
+
+
+class BorderedRectangle(_ShapeBase):
+    def __init__(self, x, y, width, height, border=1, color=(255, 255, 255),
+                 border_color=(100, 100, 100), batch=None, group=None):
+        """Create a rectangle or square.
+
+        The rectangles's anchor point defaults to the (x, y) coordinates,
+        which are at the bottom left.
+
+        :Parameters:
+            `x` : float
+                The X coordinate of the rectangle.
+            `y` : float
+                The Y coordinate of the rectangle.
+            `width` : float
+                The width of the rectangle.
+            `height` : float
+                The height of the rectangle.
+            `color` : (int, int, int)
+                The RGB color of the rectangle, specified as
+                a tuple of three ints in the range of 0-255.
+            `batch` : `~pyglet.graphics.Batch`
+                Optional batch to add the rectangle to.
+            `group` : `~pyglet.graphics.Group`
+                Optional parent group of the rectangle.
+        """
+        self._x = x
+        self._y = y
+        self._width = width
+        self._height = height
+        self._border = border
+        self._rgb = color
+        self._brgb = border_color
+
+        self._batch = batch or Batch()
+        self._group = _ShapeGroup(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA, group)
+        indices = [0, 1, 2, 0, 2, 3, 0, 4, 3, 4, 7, 3, 0, 1, 5, 0, 5, 4, 1, 2, 5, 5, 2, 6, 6, 2, 3, 6, 3, 7]
+        self._vertex_list = self._batch.add_indexed(8, GL_TRIANGLES, self._group, indices, 'v2f', 'c4B')
+        self._update_position()
+        self._update_color()
+
+    def _update_position(self):
+        if not self._visible:
+            self._vertex_list.vertices = (0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
+        else:
+            b = self._border
+            bx1 = self._x - self._anchor_x
+            by1 = self._y - self._anchor_y
+            bx2 = bx1 + self._width
+            by2 = by1 + self._height
+            ix1 = bx1 + b
+            iy1 = by1 + b
+            ix2 = bx2 - b
+            iy2 = by2 - b
+            self._vertex_list.vertices[:] = (ix1, iy1, ix2, iy1, ix2, iy2, ix1, iy2,
+                                             bx1, by1, bx2, by1, bx2, by2, bx1, by2,)
+
+    def _update_color(self):
+        opacity = int(self._opacity)
+        self._vertex_list.colors[:] = [*self._rgb, opacity] * 4 + [*self._brgb, opacity] * 4
+
+    @property
+    def width(self):
+        """The width of the rectangle.
+
+        :type: float
+        """
+        return self._width
+
+    @width.setter
+    def width(self, value):
+        self._width = value
+        self._update_position()
+
+    @property
+    def height(self):
+        """The height of the rectangle.
+
+        :type: float
+        """
+        return self._height
+
+    @height.setter
+    def height(self, value):
+        self._height = value
+        self._update_position()
+
+
+__all__ = ('Arc', 'Circle', 'Line', 'Rectangle', 'BorderedRectangle')
