@@ -1,14 +1,53 @@
-from __future__ import absolute_import
-from builtins import object
-from pyglet.libs.darwin.cocoapy import *
+# ----------------------------------------------------------------------------
+# pyglet
+# Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2020 pyglet contributors
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+#  * Redistributions of source code must retain the above copyright
+#    notice, this list of conditions and the following disclaimer.
+#  * Redistributions in binary form must reproduce the above copyright
+#    notice, this list of conditions and the following disclaimer in
+#    the documentation and/or other materials provided with the
+#    distribution.
+#  * Neither the name of pyglet nor the names of its
+#    contributors may be used to endorse or promote products
+#    derived from this software without specific prior written
+#    permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
+# ----------------------------------------------------------------------------
+
+from pyglet.libs.darwin.cocoapy import ObjCClass, ObjCSubclass, ObjCInstance
+from pyglet.libs.darwin.cocoapy import NSApplicationDidHideNotification
+from pyglet.libs.darwin.cocoapy import NSApplicationDidUnhideNotification
+from pyglet.libs.darwin.cocoapy import send_super, get_selector
+from pyglet.libs.darwin.cocoapy import PyObjectEncoding
+from pyglet.libs.darwin.cocoapy import quartz
 from .systemcursor import SystemCursor
 
 NSNotificationCenter = ObjCClass('NSNotificationCenter')
 NSApplication = ObjCClass('NSApplication')
 
-class PygletDelegate_Implementation(object):
+
+class PygletDelegate_Implementation:
     PygletDelegate = ObjCSubclass('NSObject', 'PygletDelegate')
-    
+
     @PygletDelegate.method(b'@'+PyObjectEncoding)
     def initWithWindow_(self, window):
         self = ObjCInstance(send_super(self, 'init'))
@@ -20,16 +59,16 @@ class PygletDelegate_Implementation(object):
         self._window = window
         window._nswindow.setDelegate_(self)
 
-        # Register delegate for hide and unhide notifications so that we 
+        # Register delegate for hide and unhide notifications so that we
         # can dispatch the corresponding pyglet events.
         notificationCenter = NSNotificationCenter.defaultCenter()
 
         notificationCenter.addObserver_selector_name_object_(
-            self, get_selector('applicationDidHide:'), 
+            self, get_selector('applicationDidHide:'),
             NSApplicationDidHideNotification, None)
 
         notificationCenter.addObserver_selector_name_object_(
-            self, get_selector('applicationDidUnhide:'), 
+            self, get_selector('applicationDidUnhide:'),
             NSApplicationDidUnhideNotification, None)
 
         # Flag set when we pause exclusive mouse mode if window loses key status.
@@ -47,7 +86,7 @@ class PygletDelegate_Implementation(object):
     @PygletDelegate.method('v@')
     def applicationDidHide_(self, notification):
         self._window.dispatch_event("on_hide")
-    
+
     @PygletDelegate.method('v@')
     def applicationDidUnhide_(self, notification):
         if self._window._is_mouse_exclusive and quartz.CGCursorIsVisible():
@@ -79,7 +118,7 @@ class PygletDelegate_Implementation(object):
          # Restore previous mouse visibility settings.
          self._window.set_mouse_platform_visible()
          self._window.dispatch_event("on_activate")
-    
+
     @PygletDelegate.method('v@')
     def windowDidResignKey_(self, notification):
         # Pause exclusive mouse mode if it is active.
@@ -89,11 +128,11 @@ class PygletDelegate_Implementation(object):
             # We need to prevent the window from being unintentionally dragged
             # (by the call to set_mouse_position in set_exclusive_mouse) when
             # the window is reactivated by clicking on its title bar.
-            self._window._nswindow.setMovable_(False)  # Mac OS X 10.6 
+            self._window._nswindow.setMovable_(False)  # Mac OS X 10.6
         # Make sure that cursor is visible.
         self._window.set_mouse_platform_visible(True)
         self._window.dispatch_event("on_deactivate")
-        
+
     @PygletDelegate.method('v@')
     def windowDidMiniaturize_(self, notification):
         self._window.dispatch_event("on_hide")
